=========
ChangeLog
=========
0.2
===
0.2.0
-----
- Update model file find method.
- Set ``--safe`` bool.

0.1
===
0.1.9
-----
- Fix default_connection when upgrade
- Find default app instead of default.
- Diff MySQL ddl.
- Check tortoise config.

0.1.8
-----
- Fix upgrade error when migrate.
- Fix init db sql error.
- Support change column.

0.1.7
-----
- Exclude models.Aerich.
- Add init record when init-db.
- Fix version num str.

0.1.6
-----
- update dependency_links

0.1.5
-----
- Add sqlite and postgres support.
- Fix dependency import.
- Store versions in db.

0.1.4
-----
- Fix transaction and fields import.
- Make unique index worked.
- Add cli --version.

0.1.3
-----
- Support indexes and unique_together.

0.1.2
-----
- Now aerich support m2m.
- Add cli cmd init-db.
- Change cli options.

0.1.1
-----
- Now aerich is basic worked.